飞越疯人院 (豆瓣)
Description: 飞越疯人院电影简介和剧情介绍,飞越疯人院影评、图片、预告片、影讯、论坛、在线购票
Keywords: 飞越疯人院,One Flew Over the Cuckoo's Nest,飞越疯人院影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.73豆瓣电影Top250

# 飞越疯人院 One Flew Over the Cuckoo's Nest (1975)

导演: 米洛斯·福尔曼
编剧: 劳伦斯·奥邦 / 博·古德曼 / 肯·凯西 / 达尔·瓦瑟曼
主演: 杰克·尼科尔森 / 丹尼·德维托 / 克里斯托弗·洛伊德 / 路易丝·弗莱彻 / 威尔·萨姆森 / 特德·马克兰德 / 布拉德·道里夫 / 斯加特曼·克罗索斯 / 迈克尔·贝里曼 / 彼得·布罗科 / 穆瓦科·卡姆布卡 / 威廉·达尔 / 乔西普·艾利克 / 西德尼·拉斯克 / 凯·李 / 德怀特·马费尔德 / 路易莎·莫里茨 / 威廉·雷德菲尔德 / 菲利普·罗斯 / 米米·萨奇席恩 / 文森特·斯卡维利 / 米斯·斯马尔 / 德罗斯·V·史密斯
类型: 剧情
制片国家/地区: 美国
语言: 英语
上映日期: 1975-11-19(美国)
片长: 133分钟
又名: 飞越杜鹃窝(台) / 飞越喜鹊巢
IMDb: tt0073486
豆瓣评分
引用
9.1
525413人评价
5星
63.3%
4星
30.1%
3星
6.0%
2星
0.5%
1星
0.2%
好于 98% 剧情片
想看 看过
评价:
推荐

## 飞越疯人院的剧情简介 · · · · · ·

麦克墨菲（杰克·尼科尔森 Jack Nicholson 饰）为了逃避监狱里的强制劳动，装作精神异常，被送进了精神病院，他的到来，给死气沉沉的精神病院带来了剧烈的冲击。 麦克要求看棒球比赛的电视转播，挑战了医院严格的管理制度，受到护士长拉契特（路易丝·弗莱彻 Louise Fletcher 饰）的百般阻挠；麦克带领病人出海捕鱼，振奋了他们的精神，却让院方头痛不已。院方为了惩处麦克胆大妄为、屡犯院规，决定将他永远留在疯人院。生性自由的麦克再也无法忍受疯人院的生活，他联合病友，高大的印第安人“酋长”，开始自己的计划：飞越疯人院。 本片获1975年第48届奥斯卡最佳影片，最佳男、女主角，最佳导演和最佳改编剧本五项大奖。主人公“不自由，毋宁死”的精神在当今社会仍有很大的现实意义。 ©豆瓣

## 飞越疯人院的演职员 · · · · · · ( 全部 46 )

- 米洛斯·福尔曼 导演
- 杰克·尼科尔森 饰 R·P·麦克墨菲 R.P. McMurphy
- 丹尼·德维托 演员
- 克里斯托弗·洛伊德 泰伯 Taber
- 路易丝·弗莱彻 护士长瑞秋 Nurse Ratched
- 威尔·萨姆森 饰 酋长布罗姆登 Chief Bromden

## 飞越疯人院的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片683 · 添加 )

## 飞越疯人院的获奖情况 · · · · · · ( 全部 )

- 第48届奥斯卡金像奖
- 最佳影片
- 索尔·扎恩兹 / 迈克尔·道格拉斯

- 第48届奥斯卡金像奖
- 最佳导演
- 米洛斯·福尔曼

- 第48届奥斯卡金像奖
- 最佳男主角
- 杰克·尼科尔森

## 喜欢这部电影的人也喜欢 · · · · · ·

  两杆大烟枪

  让子弹飞

  低俗小说

  疯狂的石头

  布达佩斯大饭店

  荒蛮故事

  大佛普拉斯

  无耻混蛋

  被解救的姜戈

  鬼子来了

我要写短评

## 飞越疯人院的短评 · · · · · · ( 全部 108067 条 )

热门 / 最新 / 好友

### 6136 有用 城南草木生 看过 2010-02-04 15:12:08

无论是现在还是在将来，疯人院和护士长化妆成各种形状潜伏在我们周围，飞越疯人院就永远有意义

### 2705 有用 树精 看过 2008-05-11 02:16:17

Chief给我的启示大于墨菲。一旦打破缄默，那便是行动的语言。

### 5396 有用 扭腰客 看过 2008-07-27 02:24:34

不可能飞越的，社会就是一个巨大的疯人院

### 2670 有用 Q。 看过 2009-02-02 02:57:53

“至少我试过了” ★★★★

### 1507 有用 薇羅尼卡 看过 2006-03-29 15:55:00

谁是疯子？谁又是正常人？没有答案。

> 更多短评 108067条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 飞越疯人院的影评 · · · · · · ( 全部 2484 条 )

热门 / 最新 / 好友
denovo 2005-11-18 09:57:22

## McMurphy为什么要……？

这篇影评可能有剧透

这个片子的原著和电影我都看了，对原著的印象大概更深一些，有些地方可能会记混，不过大致上应该差不太多。顺便推荐大家去读原著，从头到尾都非常精彩，很多细节在电影里都被省略了，毕竟时间有限。 看到大家在讨论McMurphy的死，忍不住想说几句。这部书/电影对五六十年代的美... (展开)
12207 264 624回应 收起
锟斤拷 2008-08-04 22:46:45

## 自由何以成为悲剧

我觉得，人们对于这部电影的口碑已经完全具备了社会学的研究价值。因为看完One Flew Over the Cuckoo's Nest的，十之八九是热泪盈眶的模范观众——他们天性善良、追求自由、尊重个性、反对桎梏、对待顽劣孩童很萌很有爱。于是，乌托邦的敌人，似乎仅仅是一小撮冷血的护士长而已... (展开)
7020 450 627回应 收起
Antigone 2009-02-13 17:13:11

## 关于《飞越疯人院》

这篇影评可能有剧透

疯人院显然是个隐喻。这隐喻在当时看来便似乎太浅显，何况今天已经有不少人看过了《肖申克的救赎》和《楚门的世界》；当然，有些人会愿意扯上《看上去很美》，姑且算它一个吧。 麦克墨菲显然是个混混，而且有点小聪明，靠着装疯卖傻躲避了牢狱之灾——虽然代价是被送进... (展开)
3029 77 202回应 收起
远の音 2007-08-06 01:13:38

## 黎明之前夜有多长。

凌晨2点。没有月亮。夜是那么清冷。它似一滴滴浑浊的雨水。透过头颅顺理成章的凉到我的脚尖。坐在窗台上。每段日子都显得毫无意义。重复的今天和昨天又有什么分别？一切期待都被泯灭。空气里散发着寂寞的气味。潮湿的如同某种霉菌。顺着呼吸进入我的身体。在每个夜里独自与自己... (展开)
1204 140 159回应 收起
orang2e 2006-02-11 20:54:07

## 要飞越的其实是我们的心

昨天晚上终于有空安静下来，刚好也很有看部好片子的心情，于是翻出了这部《飞越疯人院》。好电影就是这样的，无论哪个时代何种社会背景都不会影响电影所能传达给观众的思想，因为真理是永远都不变的。什么是好电影？对于我来说，一部好电影的意义就在于它能让我反复思考，找出... (展开)
779 38 74回应 收起
裸踝 2009-10-16 00:29:39

## 自由与制度的悖论

1989－1990年，北京摄影师吕楠历时两年，走访了全国十个省市38家精神病院和上百个精神病患者家庭，完成了一部名为《被人遗忘的人：中国精神病人生存状况》的摄影集。他在文案里记录了自己第一次去医院拍摄时的一件事。在北京安定医院一间病房，有一个病人正往外看，他想拍他，... (展开)
529 25 41回应 收起
小梳子 2005-11-17 00:09:41

## “至少我试过了”

电影中，印象最深的就是这句“我试过了”。当麦克莫菲和同伴们打赌能搬动饮水机砸开窗子逃走，大家都说麦克搬不动，结果，麦克真的就没有那么大的力气，没有搬动，但是他说了一句很经典的话“至少我试过了”。影片后来告诉我们，大多数在精神病院的患者都是自愿呆在里面的，没... (展开)
394 44 77回应 收起
elya妞 2008-07-30 10:03:43

## ～飞跃疯人院～

一、 关于本片的背景 （一）、原著背景 《飞越疯人院》原本为美国作家肯•克西于１９６２年发表的小说，作者以疯人院暗喻美国的社会体制，全文充满了浓烈的反体制提倡个人自由意味。而在小说的发表年代（60年代）也正是美国社会动荡不安的年代，二战结束后的东西方冷战、麦卡... (展开)
328 5 22回应 收起
果冻 2009-02-28 23:59:13

## 疯人院：秩序与自由之间的博弈

这篇影评可能有剧透

看完电影的结局，我非常震撼和感动。但仔细考察这部电影的环境和演进，我认为是这并不是一部完全歌颂革命和自由的电影，虽然它包含着反抗精神和自由精神的因素。 　　 疯人院是精神病人的聚居地。男主角麦克默菲进入疯人院之前，这里秩序井然，医生和看护们与病人互道早安，按... (展开)
273 9 17回应 收起
奶味鸭姐 2010-10-24 18:57:57

## 不是英雄，只是冲不过高墙的病人。

这篇影评可能有剧透

我恨不得要给这部电影打6星。 难得一次没有事先看电影介绍和豆瓣影评，我很高兴没被他人的主观意见所影响。 在对一部电影的认知为0的情况下去观看它，反而能看出更多的东西。 我喜欢影片诙谐的基调，音乐亦配合得极好，有很多次令人忍俊不禁，然而高潮却一次又一次隐藏在平静之... (展开)
236 5 30回应 收起

> 更多影评 2484篇

添加新讨论

## 讨论区 · · · · · ·

虽然主题意义很好，但电影着实不咋地，果然是疯人... | 来自permanent | 23 回应 | 2022-11-23 15:57:20
男主为什么不在第一次成功出逃时就彻底逃走呢？ | 来自1 |  | 2022-11-23 10:21:02
男主活该 | 来自不是美女 | 2 回应 | 2022-11-20 18:43:15
求问一个没看懂的情节 | 来自🐰 | 2 回应 | 2022-11-17 17:28:54
愿我们都能飞越内心的牢笼 | 来自豆友y26nQgjGCM |  | 2022-11-13 17:24:22

> 去这部影片的讨论区（全部396条）

## 关于《飞越疯人院》的问题 · · · · · · ( 全部43个 )

- 麦克墨菲被摘除脑叶前一晚上为什么不跑? 21人回答
- 为什么大家对男主的死亡结局唏嘘不已？他的悲剧不是自己造成的吗？ 37人回答

> 全部43个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 北京电影学院硕士要看的100部电影 (悲`馨)
- 心理学电影(一句话剧透,不喜勿入) (何学卿)
- 【励志电影】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)

## 谁在看这部电影 · · · · · ·

- 再见白丝
  3分钟前 想看
- 杨坚强
  5分钟前 看过
- 纱织NaNa
  8分钟前 想看

819419人看过 / 432352人想看

订阅飞越疯人院的评论:
feed: rss 2.0